@@ -19,26 +19,19 @@ def download_lato_font(verbose=False):
             )
         return
 
-    # if we are running in Google Colab, we need to install the correct font:
+    # if we are running in Google Colab, we need to install the correct font
+    # from https://www.1001freefonts.com/d/5722/lato.zip to the right place:
     mpl_fonts = "/usr/local/lib/python3.6/dist-packages/matplotlib/mpl-data/fonts/ttf/"
-    lato_url = "https://www.1001freefonts.com/d/5722/lato.zip"
-
-    if verbose:
-        print("Downloading Lato font from {} ...".format(mpl_fonts))
-
-    with open("lato.zip", "wb") as handle:
-        handle.write(get(lato_url).content)
 
     if verbose:
         print("... extracting lato.zip contents to mpl-data/fonts ...")
 
-    with ZipFile("lato.zip", "r") as zip:
+    with ZipFile("fonts/lato.zip", "r") as zip:
         zip.extractall(mpl_fonts)
 
     if verbose:
         print("... cleaning up ...")
 
-    os.remove("lato.zip")
     os.remove(mpl_fonts + "OFL.txt")
 
     if verbose:
